==> binnie-mods-1.12.2-2.5.0.94-sources.jar: binnie/extrabees/alveary/AbstractAlvearyLogic.java <==
package binnie.extrabees.alveary;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import net.minecraft.client.gui.inventory.GuiContainer;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.util.EnumFacing;

import net.minecraftforge.common.capabilities.Capability;
import net.minecraftforge.common.capabilities.ICapabilityProvider;
import net.minecraftforge.energy.IEnergyStorage;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.apiculture.IBeeGenome;
import forestry.api.apiculture.IBeeListener;
import forestry.api.apiculture.IBeeModifier;
import forestry.api.genetics.IIndividual;

import binnie.extrabees.client.gui.AbstractAlvearyContainer;

public abstract class AbstractAlvearyLogic implements IBeeModifier, IBeeListener, ICapabilityProvider {

	@Override
	public float getTerritoryModifier(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getMutationModifier(@Nonnull IBeeGenome genome, @Nonnull IBeeGenome mate, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getLifespanModifier(@Nonnull IBeeGenome genome, @Nullable IBeeGenome mate, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getProductionModifier(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getFloweringModifier(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getGeneticDecay(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public boolean isSealed() {
		return false;
	}

	@Override
	public boolean isSelfLighted() {
		return false;
	}

	@Override
	public boolean isSunlightSimulated() {
		return false;
	}

	@Override
	public boolean isHellish() {
		return false;
	}

	@Override
	public void wearOutEquipment(int amount) {

	}

	@Override
	public void onQueenDeath() {

	}

	@Override
	public boolean onPollenRetrieved(@Nonnull IIndividual pollen) {
		return false;
	}

	public void updateClient(TileEntityExtraBeesAlvearyPart tile) {

	}

	public void updateServer(TileEntityExtraBeesAlvearyPart tile) {

	}

	@Nullable
	@SideOnly(Side.CLIENT)
	public GuiContainer getGui(@Nonnull EntityPlayer player, int data) {
		return null;
	}

	@Nullable
	public AbstractAlvearyContainer getContainer(@Nonnull EntityPlayer player, int data) {
		return null;
	}

	@Override
	public boolean hasCapability(@Nonnull Capability<?> capability, @Nullable EnumFacing facing) {
		return false;
	}

	@Nullable
	@Override
	public <T> T getCapability(@Nonnull Capability<T> capability, @Nullable EnumFacing facing) {
		return null;
	}

	public IEnergyStorage getEnergyStorage() {
		return null;
	}

	public boolean hasGui() {
		return false;
	}
}

==> binnie-mods-1.12.2-2.5.0.119-sources.jar: binnie/extrabees/alveary/AbstractAlvearyLogic.java <==
package binnie.extrabees.alveary;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import net.minecraft.client.gui.inventory.GuiContainer;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.EnumFacing;

import net.minecraftforge.common.capabilities.Capability;
import net.minecraftforge.common.capabilities.ICapabilityProvider;
import net.minecraftforge.energy.IEnergyStorage;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.apiculture.IBeeGenome;
import forestry.api.apiculture.IBeeListener;
import forestry.api.apiculture.IBeeModifier;
import forestry.api.core.INbtReadable;
import forestry.api.core.INbtWritable;
import forestry.api.genetics.IIndividual;

import binnie.extrabees.client.gui.AbstractAlvearyContainer;

public abstract class AbstractAlvearyLogic implements IBeeModifier, IBeeListener, ICapabilityProvider, INbtWritable, INbtReadable {
	static final String INVENTORY_NBT_KEY = "inventory";
	static final String ENERGY_NBT_KEY = "Energy";

	@Override
	public float getTerritoryModifier(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getMutationModifier(@Nonnull IBeeGenome genome, @Nonnull IBeeGenome mate, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getLifespanModifier(@Nonnull IBeeGenome genome, @Nullable IBeeGenome mate, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getProductionModifier(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getFloweringModifier(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public float getGeneticDecay(@Nonnull IBeeGenome genome, float currentModifier) {
		return 1.0f;
	}

	@Override
	public boolean isSealed() {
		return false;
	}

	@Override
	public boolean isSelfLighted() {
		return false;
	}

	@Override
	public boolean isSunlightSimulated() {
		return false;
	}

	@Override
	public boolean isHellish() {
		return false;
	}

	@Override
	public void wearOutEquipment(int amount) {

	}

	@Override
	public void onQueenDeath() {

	}

	@Override
	public boolean onPollenRetrieved(@Nonnull IIndividual pollen) {
		return false;
	}

	public void updateClient(TileEntityExtraBeesAlvearyPart tile) {

	}

	public void updateServer(TileEntityExtraBeesAlvearyPart tile) {

	}

	@Override
	public void readFromNBT(NBTTagCompound nbt) {
	}

	@Override
	public NBTTagCompound writeToNBT(NBTTagCompound nbt) {
		return nbt;
	}

	@Nullable
	@SideOnly(Side.CLIENT)
	public GuiContainer getGui(@Nonnull EntityPlayer player, int data) {
		return null;
	}

	@Nullable
	public AbstractAlvearyContainer getContainer(@Nonnull EntityPlayer player, int data) {
		return null;
	}

	@Override
	public boolean hasCapability(@Nonnull Capability<?> capability, @Nullable EnumFacing facing) {
		return false;
	}

	@Nullable
	@Override
	public <T> T getCapability(@Nonnull Capability<T> capability, @Nullable EnumFacing facing) {
		return null;
	}

	public IEnergyStorage getEnergyStorage() {
		return null;
	}

	public boolean hasGui() {
		return false;
	}
}
